@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2011 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.5. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "bookmarkPlugin.h"
@@ -74,7 +74,7 @@ void bookmarkPlugin::parseBookmarks()
     }
     addSeparator();
     QAction* edit_bookmarks = addAction(tr("Edit Bookmarks"), this, SIGNAL(editBookmarks()));
-    edit_bookmarks->setStatusTip(tr("Edit Bookmarks"));
+    edit_bookmarks->setStatusTip(tr("Edit bookmarks"));
     edit_bookmarks->setIcon(QIcon(":/icons/icons/edit.png"));
 }
 
