@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2011 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.5. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2b.h"
@@ -79,9 +79,9 @@ void c2b::configure(int index)
     if (index > -1)
         c->setPage(index);
     if (c->exec() == QDialog::Accepted)
-        showMessage(tr("Configuration Saved."));
+        showMessage(tr("Configuration was saved."));
     else
-        showMessage(tr("Configure Cancelled."));
+        showMessage(tr("Configuration was cancelled."));
     delete c;
 }
 
