@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2011 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.5. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "authorString.h"
@@ -233,7 +233,7 @@ QString authorString::toBibTeX(const QString& author, bool full_form)
             is_current_reversed = false;
     }
 
-    authors.removeAll("");
+    authors.removeAll(QString());
     _author_string = authors.join(" and ");
     // Restore Composite Names white spaces
     _author_string.replace("_i_", " i ");
