@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2011 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.5. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "bibExtractor.h"
@@ -128,7 +128,7 @@ int bibExtractor::extract(const QStringList& input_fns, const QString& output_fn
         }
         else
             logMessage(tr("Warning: Skip writing reference for file %1.").arg(input_fn));
-        logMessage("");
+        logMessage(QString());
     }
     if (bibtex.isEmpty())
         logMessage(tr("Warning: No reference extracted."));
