@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2011 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.5. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "heuristicBibParser.h"
@@ -805,7 +805,7 @@ void heuristicBibParser::guessVolumePagesYear(const QString& text)
 void heuristicBibParser::guessVolumeYearPages(const QString& text)
 {
     // Does several volume year pages formats
-    if (_reliable_pages && _reliable_volume)
+    if (_reliable_number && _reliable_volume)
         return;
     // J. Sci. 203 (2003) 209.
     QRegExp rxH("(\\d+)\\s*\\(" + _current_reference.value(_year) + "\\)\\s*(" + _hyphen_pages + ')');
@@ -836,7 +836,20 @@ void heuristicBibParser::guessYearVolumePages(const QString& text)
         _reliable_volume = true;
         return;
     }
-    if (_reliable_pages && _reliable_volume)
+    // J. Sci. (1999), 86, 3, pp. 635-648
+    rxH = QRegExp("\\(" + _current_reference.value(_year) + "\\)" + "\\s*[,:;]\\s*(\\d+)\\s*[,:;]\\s*(" +
+                  _hyphen_nums + ")\\s*[,:;]\\s*(?:pp)?\\.?\\s*(" + _hyphen_pages + ')');
+    nH = rxH.indexIn(text);
+    if (nH > -1)
+    {
+        _current_reference[_volume] = _bpP->parse(_volume, rxH.cap(1));
+        _current_reference[_number] = _bpP->parse(_number, rxH.cap(2));
+        _current_reference[_pages] = _bpP->parse(_pages, rxH.cap(3));
+        _reliable_pages = true;
+        _reliable_volume = true;
+        return;
+    }
+    if (_reliable_volume)
         return;
     // J. Sci. 1995 January 25; 247:536-40.
     // J. Sci. 2005, 103, 818
