@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2011 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.5. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "settings.h"
@@ -299,7 +299,7 @@ const QString settings::configuredFilename()
 {
     const QCoreApplication* capp = QCoreApplication::instance();
     QStringList arguments(capp->arguments());
-    arguments.removeAll("");
+    arguments.removeAll(QString());
     QString filename;
     for (int i = 1; i < capp->argc() - 1; ++i)
         if (QString(arguments.at(i)) == "--conf" || QString(arguments.at(i)) == "--configure")
@@ -331,7 +331,7 @@ const QString settings::configuredFilename()
 void settings::readCommandLine()
 {
     QStringList arguments(_c2bApp->arguments());
-    arguments.removeAll("");
+    arguments.removeAll(QString());
     int actions(0);
     for (int i = 1; i < arguments.count(); ++i)
         if (arguments.at(i).startsWith('-'))
