@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2011 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.5. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bAnnote.h"
@@ -34,14 +34,14 @@ c2bAnnote::c2bAnnote(QWidget* parentw) : QMainWindow(parentw)
     connect(c2b_resources, SIGNAL(statusMessage(const QString&)), this, SLOT(showMessage(const QString&)));
 
     QAction* act = new QAction(QIcon(QString::fromUtf8(":/icons/icons/edit.png")), tr("Edit Note"), this);
-    act->setShortcut(QKeySequence("E"));
+    act->setShortcut(QKeySequence(Qt::Key_E));
     act->setStatusTip(tr("Edit TeX note"));
     c2bUtils::addSeparator(_view_port);
     _view_port->addAction(act);
     connect(act, SIGNAL(triggered()), this, SLOT(edit()));
 
     act = new QAction(QIcon(QString::fromUtf8(":/icons/icons/configure.png")), tr("Configure"), this);
-    act->setShortcut(QKeySequence("C"));
+    act->setShortcut(QKeySequence(Qt::Key_C));
     act->setStatusTip(tr("Configure cb2Bib Annote"));
     c2bUtils::addSeparator(_view_port);
     _view_port->addAction(act);
@@ -128,7 +128,7 @@ void c2bAnnote::setWindowTitle(const QString& title)
     else
         QMainWindow::setWindowTitle(title + " - cb2Bib");
     if (title == "New Note")
-        showMessage(tr("Press E to Edit or %1 for Help").arg(QKeySequence(QKeySequence::HelpContents).toString()));
+        showMessage(tr("Press E to Edit and %1 for Help.").arg(QKeySequence(QKeySequence::HelpContents).toString()));
 }
 
 void c2bAnnote::showMessage(const QString& ms)
