@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2011 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.5. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bBibMenu.h"
@@ -83,7 +83,7 @@ c2bBibMenu::c2bBibMenu(QWidget* parentw) : QMenu(parentw), _keyboard_selection(0
     addSeparator();
     addMenu(submenu);
     addSeparator();
-    _any_pattern_action = addAction("");
+    _any_pattern_action = addAction(QString());
 }
 
 QAction* c2bBibMenu::exec(const QPoint& p)
