@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2011 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.5. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bCiter.h"
@@ -267,12 +267,12 @@ void c2bCiter::setActions()
     c2bUtils::addSeparator(this);
 
     a = new QAction(this);
-    a->setText(tr("Open directory"));
+    a->setText(tr("Open Directory"));
     a->setShortcut(QKeySequence(QKeySequence::Open));
     addAction(a);
     connect(a, SIGNAL(triggered()), this, SLOT(openDirectory()));
     a = new QAction(this);
-    a->setText(tr("Open files"));
+    a->setText(tr("Open Files"));
     a->setShortcut(QKeySequence(Qt::ALT + Qt::Key_O));
     addAction(a);
     connect(a, SIGNAL(triggered()), this, SLOT(openFiles()));
@@ -287,13 +287,13 @@ void c2bCiter::setActions()
 
     a = new QAction(this);
     a->setText(tr("Search In Files"));
-    a->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_F));
+    a->setShortcut(QKeySequence(QKeySequence::Find));
     addAction(a);
     connect(a, SIGNAL(triggered()), this, SLOT(doSearchInFiles()));
     c2bUtils::addSeparator(this);
 
     a = new QAction(this);
-    a->setText(tr("Set LyX pipe"));
+    a->setText(tr("Set LyX Pipe"));
     a->setShortcut(QKeySequence(Qt::ALT + Qt::Key_L));
     addAction(a);
     connect(a, SIGNAL(triggered()), _citerP, SLOT(setLyXPipe()));
@@ -318,7 +318,7 @@ void c2bCiter::setActions()
 
     a = new QAction(this);
     a->setText(tr("Exit"));
-    a->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_Q));
+    a->setShortcut(QKeySequence(QKeySequence::Quit));
     addAction(a);
     connect(a, SIGNAL(triggered()), c2b::instance(), SLOT(exitRequested()));
 }
@@ -540,7 +540,7 @@ void c2bCiter::openUrl()
         return;
     const QString u(_citations->dataUrl(ui.citationsView->currentIndex()));
     if (u.isEmpty())
-        showMessage(tr("No Url entry in this reference."));
+        showMessage(tr("No URL entry in this reference."));
     else
     {
         showMessage(tr("Opening %1").arg(QUrl::fromPercentEncoding(u.toUtf8())));
