@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2011 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.5. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bEditor.h"
@@ -72,8 +72,8 @@ editorbookmark=Description|Target file name|Shortcut|Icon file name
 
 <pre style="color : #005600; background : #d5d5d5; border : #6D8CC3 solid 1px;">
 # Bookmark Examples:
-# - A Url:
-editorbookmark=Url Description|http://www.molspaces.com/d_cb2bib-c2beditor.php#bookmarks||
+# - A URL:
+editorbookmark=URL Description|http://www.molspaces.com/d_cb2bib-c2beditor.php#bookmarks||
 # - A separator, which is a blank line:
 editorbookmark=
 # - A TeX document, which will be opened with its default application:
@@ -123,15 +123,14 @@ editorbookmark=Application Description|/opt/kde3/bin/kile|Alt+K|/usr/share/icons
 summary="Summary table of Right-Click Menu Functionality">
 <tr> <th valign="top">Keys</th> <th valign="top">Action</th></tr>
 <tr> <td valign="top">Ctrl+F</td> <td valign="top">Find in text</td></tr>
-<tr> <td valign="top"></td> <td valign="top">Wrap text</td></tr>
-<tr> <td valign="top"></td> <td valign="top">Unwrap text</td></tr>
+<tr> <td valign="top"></td> <td valign="top">Toggle word wrapping</td></tr>
 <tr> <td valign="top"></td> <td valign="top">Selection to LaTeX</td></tr>
 <tr> <td valign="top"></td> <td valign="top">Selection to Unicode</td></tr>
-<tr> <td valign="top"></td> <td valign="top">Journals to Full Name</td></tr>
-<tr> <td valign="top"></td> <td valign="top">Journals to Abbreviated Name</td></tr>
-<tr> <td valign="top"></td> <td valign="top">Update Documents Metadata</td></tr>
+<tr> <td valign="top"></td> <td valign="top">Journals to full name</td></tr>
+<tr> <td valign="top"></td> <td valign="top">Journals to abbreviated name</td></tr>
+<tr> <td valign="top"></td> <td valign="top">Update documents metadata</td></tr>
 <tr> <td valign="top">Shift+Ins</td> <td valign="top">Paste current BibTeX</td></tr>
-<tr> <td valign="top">Alt+P</td> <td valign="top">Save and Postprocess BibTeX file</td></tr>
+<tr> <td valign="top">Alt+P</td> <td valign="top">Save and postprocess BibTeX file</td></tr>
 </table></center>
 \endhtmlonly
 
@@ -142,14 +141,14 @@ summary="Summary table of Right-Click Menu Functionality">
 <center><table cellpadding="4" cellspacing="2" border="1"
 summary="Summary table of References Right-Click Menu Functionality">
 <tr> <th valign="top">Keys</th> <th valign="top">Action</th></tr>
-<tr> <td valign="top">Alt+C</td> <td valign="top">Cite Selected Entries</td></tr>
-<tr> <td valign="top"></td> <td valign="top">Open Document File</td></tr>
+<tr> <td valign="top">Alt+C</td> <td valign="top">Cite selected entries</td></tr>
+<tr> <td valign="top"></td> <td valign="top">Open document file</td></tr>
 <tr> <td valign="top"></td> <td valign="top">Browse by DOI</td></tr>
-<tr> <td valign="top"></td> <td valign="top">Web Search by Authors</td></tr>
-<tr> <td valign="top"></td> <td valign="top">Web Search by Title</td></tr>
-<tr> <td valign="top"></td> <td valign="top">Web Search Settings</td></tr>
-<tr> <td valign="top"></td> <td valign="top">Clear Entry Selection</td></tr>
-<tr> <td valign="top"></td> <td valign="top">Refresh List and Browser View</td></tr>
+<tr> <td valign="top"></td> <td valign="top">Web search by Author</td></tr>
+<tr> <td valign="top"></td> <td valign="top">Web search by Title</td></tr>
+<tr> <td valign="top"></td> <td valign="top">Web search settings</td></tr>
+<tr> <td valign="top"></td> <td valign="top">Clear entry selection</td></tr>
+<tr> <td valign="top"></td> <td valign="top">Refresh list and browser</td></tr>
 </table></center>
 \endhtmlonly
 
@@ -160,12 +159,12 @@ summary="Summary table of References Right-Click Menu Functionality">
 <center><table cellpadding="4" cellspacing="2" border="1"
 summary="Summary table of Browser Right-Click Menu Functionality">
 <tr> <th valign="top">Keys</th> <th valign="top">Action</th></tr>
-<tr> <td valign="top">Alt+C</td> <td valign="top">Cite Selected Entries</td></tr>
-<tr> <td valign="top"></td> <td valign="top">Local Search for selected text</td></tr>
-<tr> <td valign="top"></td> <td valign="top">Web Search for selected text</td></tr>
-<tr> <td valign="top"></td> <td valign="top">Web Search Settings</td></tr>
-<tr> <td valign="top"></td> <td valign="top">Clear Entry Selection</td></tr>
-<tr> <td valign="top"></td> <td valign="top">Refresh List and Browser View</td></tr>
+<tr> <td valign="top">Alt+C</td> <td valign="top">Cite selected entries</td></tr>
+<tr> <td valign="top"></td> <td valign="top">Local search for selected text</td></tr>
+<tr> <td valign="top"></td> <td valign="top">Web search for selected text</td></tr>
+<tr> <td valign="top"></td> <td valign="top">Web search settings</td></tr>
+<tr> <td valign="top"></td> <td valign="top">Clear entry selection</td></tr>
+<tr> <td valign="top"></td> <td valign="top">Refresh list and browser</td></tr>
 </table></center>
 \endhtmlonly
 
@@ -280,6 +279,7 @@ void c2bEditor::initEditor()
 
     // Standard shortcuts
     ui.fileCloseAction->setShortcut(QKeySequence(QKeySequence::Close));
+    ui.fileExitAction->setShortcut(QKeySequence(QKeySequence::Quit));
     ui.fileOpenAction->setShortcut(QKeySequence(QKeySequence::Open));
     ui.fileSaveAction->setShortcut(QKeySequence(QKeySequence::Save));
 #if QT_VERSION >= 0x040500
@@ -316,8 +316,8 @@ void c2bEditor::setEditorMode()
     {
         _shP = new c2bREHighlighter(_editorP->document());
         ui.fileExecAction->setText(tr("Restart Recognition"));
-        ui.fileExecAction->setStatusTip(tr("Restart Recognition"));
-        ui.fileExecAction->setShortcut(tr("Alt+R"));
+        ui.fileExecAction->setStatusTip(tr("Restart recognition"));
+        _settingsP->setKeysequence("Shortcuts/Editor/", ui.fileExecAction);
         connect(this, SIGNAL(execute()), this, SIGNAL(restartEngine()));
         ui.toolBar->setVisible(_settingsP->value("c2bEditor/ToolBar", true).toBool());
         setViewMode(true);
@@ -326,8 +326,8 @@ void c2bEditor::setEditorMode()
     {
         _shP = new c2bREHighlighter(_editorP->document());
         ui.fileExecAction->setText(tr("Restart Network Query"));
-        ui.fileExecAction->setStatusTip(tr("Restart Network Query"));
-        ui.fileExecAction->setShortcut(tr("Alt+N"));
+        ui.fileExecAction->setStatusTip(tr("Restart network query"));
+        _settingsP->setKeysequence("Shortcuts/Editor/", ui.fileExecAction);
         connect(this, SIGNAL(execute()), this, SIGNAL(restartQuery()));
         ui.toolBar->setVisible(_settingsP->value("c2bEditor/ToolBar", true).toBool());
         setViewMode(true);
@@ -351,8 +351,8 @@ void c2bEditor::setEditorMode()
         connect(_editorP->updateMetadataAction, SIGNAL(triggered()), this, SLOT(updateMetadata()));
         connect(_c2b_mainP, SIGNAL(addedBibToFile(const QString&)), this, SLOT(reload(const QString&)));
         ui.fileExecAction->setText(tr("Save and Postprocess"));
-        ui.fileExecAction->setStatusTip(tr("Save and Postprocess"));
-        ui.fileExecAction->setShortcut(tr("Alt+P"));
+        ui.fileExecAction->setStatusTip(tr("Save and postprocess"));
+        _settingsP->setKeysequence("Shortcuts/Editor/", ui.fileExecAction);
         connect(this, SIGNAL(execute()), this, SLOT(postProcess()));
 
         // Browser
@@ -360,6 +360,7 @@ void c2bEditor::setEditorMode()
         _browserP->setFont(QFont(QFont().family(), _settingsP->value("c2bEditor/BrowserFontPointSize", QFont().pointSize()).toInt()));
         _stackedWidgetP->addWidget(_browserP);
         ui.viewEditorModeAction->setVisible(true);
+        _settingsP->setKeysequence("Shortcuts/Editor/", ui.viewEditorModeAction);
         connect(ui.viewEditorModeAction, SIGNAL(triggered(bool)), this, SLOT(setViewMode(bool)));
         connect(ui.viewZoomInAction, SIGNAL(triggered()), _browserP, SLOT(zoomIn()));
         connect(ui.viewZoomOutAction, SIGNAL(triggered()), _browserP, SLOT(zoomOut()));
@@ -381,9 +382,11 @@ void c2bEditor::setEditorMode()
         ui.viewEditorModeAction->setChecked(edit_mode);
         setViewMode(edit_mode);
         ui.setLyXPipeAction->setVisible(true);
+        _settingsP->setKeysequence("Shortcuts/Editor/", ui.setLyXPipeAction);
 
         // Export entries
         ui.fileExportEntriesAction->setVisible(true);
+        _settingsP->setKeysequence("Shortcuts/Editor/", ui.fileExportEntriesAction);
         connect(ui.fileExportEntriesAction, SIGNAL(triggered()), this, SLOT(exportEntries()));
         connect(_referencesP, SIGNAL(hasSelectedItems(bool)), ui.fileExportEntriesAction, SLOT(setEnabled(bool)));
     }
@@ -506,9 +509,9 @@ bool c2bEditor::fileSaveAs()
 {
     QString filename;
     if (_editor_mode == "BibTeX")
-        filename = c2bFileDialog::getSaveFilename(this, "", _editor_fn, "BibTeX (*.bib);;All (*)");
+        filename = c2bFileDialog::getSaveFilename(this, QString(), _editor_fn, "BibTeX (*.bib);;All (*)");
     else
-        filename = c2bFileDialog::getSaveFilename(this, "", _editor_fn, "Text (*.txt);;All (*)");
+        filename = c2bFileDialog::getSaveFilename(this, QString(), _editor_fn, "Text (*.txt);;All (*)");
     if (filename.isEmpty() || filename.contains("unnamed_"))
         return false;
     const QString old_name(_editor_fn);
