@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2011 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.5. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bExportDialog.h"
@@ -74,7 +74,7 @@ void c2bExportDialog::_export()
     }
     if (_ed.copy_documents)
     {
-        const QString ddname(c2bUtils::documentAbsoluteName(_ed.relative_dir, _ed.export_fn, _ed.documents_dir, "") + QDir::separator());
+        const QString ddname(c2bUtils::documentAbsoluteName(_ed.relative_dir, _ed.export_fn, _ed.documents_dir, QString()) + QDir::separator());
         QDir doc_dir(ddname);
         if (!doc_dir.exists())
             if (!doc_dir.mkpath(ddname))
@@ -102,7 +102,7 @@ void c2bExportDialog::getExportFile()
 void c2bExportDialog::getDocumentsDirectory()
 {
     const QString dir(c2bUtils::documentAbsoluteName(ui.RelativeDocumentDirectory->isChecked(), ui.ExportFile->text(),
-                      ui.DocumentsDirectory->text(), ""));
+                      ui.DocumentsDirectory->text(), QString()));
     QString new_dir(c2bFileDialog::getExistingDirectory(this, tr("Select documents directory"), dir));
     if (!new_dir.isEmpty())
     {
