@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2011 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.5. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bNetworkQueryInfo.h"
@@ -143,7 +143,7 @@ const QString c2bNetworkQueryInfo::encodeLink(const QString& ln) const
             {
                 QString fld;
                 if (name == "pages")
-                    fld = _bpP->field(name).replace(QRegExp("-.+$"), "");
+                    fld = _bpP->field(name).replace(QRegExp("-.+$"), QString());
                 else if (name == "author")
                 {
                     fld = _bpP->field(name);
