@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2011 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.5. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bPdfImport.h"
@@ -421,7 +421,7 @@ bool c2bPdfImport::event(QEvent* qevent)
 
 void c2bPdfImport::selectFiles()
 {
-    QStringList fns(c2bFileDialog::getOpenFilenames(this, "",
+    QStringList fns(c2bFileDialog::getOpenFilenames(this, QString(),
                     settings->fileName("c2bPdfImport/LastFile"),
                     tr("Portable Document Format (*.pdf);;All (*)")));
     if (fns.isEmpty())
