@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2011 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.5. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bReferenceList.h"
@@ -60,7 +60,7 @@ c2bReferenceList::c2bReferenceList(c2bTextEdit* ed, c2bTextBrowser* br, QWidget*
     header.append(tr("ID"));
     header.append(tr("Year"));
     header.append(tr("Journal"));
-    header.append(tr("Authors"));
+    header.append(tr("Author"));
     header.append(tr("Title"));
     ui.listView->sortItems(_key_index, Qt::AscendingOrder);
     ui.listView->setHeaderLabels(header);
@@ -68,62 +68,68 @@ c2bReferenceList::c2bReferenceList(c2bTextEdit* ed, c2bTextBrowser* br, QWidget*
     ui.listView->setContextMenuPolicy(Qt::ActionsContextMenu);
 
     citeEntryAction = new QAction(this);
-    citeEntryAction->setShortcut(tr("Alt+C"));
     citeEntryAction->setText(tr("Cite Selected Entries"));
+    _settingsP->setKeysequence("Shortcuts/Editor/", citeEntryAction);
     connect(citeEntryAction, SIGNAL(triggered()), this, SLOT(citeEntry()));
     ui.listView->addAction(citeEntryAction);
 
     c2bUtils::addSeparator(ui.listView);
     openFileAction = new QAction(this);
     openFileAction->setText(tr("Open Document File"));
-    openFileAction->setStatusTip(tr("Open Document File"));
+    openFileAction->setStatusTip(tr("Open document file"));
+    _settingsP->setKeysequence("Shortcuts/Editor/", openFileAction);
     connect(openFileAction, SIGNAL(triggered()), this, SLOT(openFile()));
     ui.listView->addAction(openFileAction);
 
     openUrlAction = new QAction(this);
-    openUrlAction->setText(tr("Open Document Url"));
-    openUrlAction->setStatusTip(tr("Open Document Url"));
+    openUrlAction->setText(tr("Open Document URL"));
+    openUrlAction->setStatusTip(tr("Open document URL"));
+    _settingsP->setKeysequence("Shortcuts/Editor/", openUrlAction);
     connect(openUrlAction, SIGNAL(triggered()), this, SLOT(openUrl()));
     ui.listView->addAction(openUrlAction);
 
     openDOIAction = new QAction(this);
     openDOIAction->setText(tr("Browse Reference by DOI"));
-    openDOIAction->setStatusTip(tr("Browse Reference by DOI"));
+    openDOIAction->setStatusTip(tr("Browse reference by DOI"));
+    _settingsP->setKeysequence("Shortcuts/Editor/", openDOIAction);
     connect(openDOIAction, SIGNAL(triggered()), this, SLOT(openDOI()));
     ui.listView->addAction(openDOIAction);
 
     c2bUtils::addSeparator(ui.listView);
     openAuthorsWebSearchAction = new QAction(this);
-    openAuthorsWebSearchAction->setText(tr("Web Search by Authors"));
-    openAuthorsWebSearchAction->setStatusTip(tr("Web Search by Authors"));
+    openAuthorsWebSearchAction->setText(tr("Web Search by Author"));
+    openAuthorsWebSearchAction->setStatusTip(tr("Web search by Author"));
+    _settingsP->setKeysequence("Shortcuts/Editor/", openAuthorsWebSearchAction);
     connect(openAuthorsWebSearchAction, SIGNAL(triggered()), this, SLOT(openAuthorWebSearch()));
     ui.listView->addAction(openAuthorsWebSearchAction);
     openTitleWebSearchAction = new QAction(this);
     openTitleWebSearchAction->setText(tr("Web Search by Title"));
-    openTitleWebSearchAction->setStatusTip(tr("Web Search by Title"));
+    openTitleWebSearchAction->setStatusTip(tr("Web search by Title"));
+    _settingsP->setKeysequence("Shortcuts/Editor/", openTitleWebSearchAction);
     connect(openTitleWebSearchAction, SIGNAL(triggered()), this, SLOT(openTitleWebSearch()));
     ui.listView->addAction(openTitleWebSearchAction);
 
     c2bUtils::addSeparator(ui.listView);
     webSearchSettingsAction = new QAction(this);
     webSearchSettingsAction->setText(tr("Web Search Settings"));
-    webSearchSettingsAction->setStatusTip(tr("Web Search Settings"));
+    webSearchSettingsAction->setStatusTip(tr("Web search settings"));
+    _settingsP->setKeysequence("Shortcuts/Editor/", webSearchSettingsAction);
     connect(webSearchSettingsAction, SIGNAL(triggered()), this, SLOT(webSearchSettings()));
     ui.listView->addAction(webSearchSettingsAction);
 
     c2bUtils::addSeparator(ui.listView);
     clearSelectionsAction = new QAction(this);
-    clearSelectionsAction->setShortcut(Qt::Key_Delete);
     clearSelectionsAction->setText(tr("Clear Entry Selection"));
-    clearSelectionsAction->setStatusTip(tr("Clear Entry Selection"));
+    clearSelectionsAction->setStatusTip(tr("Clear entry selection"));
+    _settingsP->setKeysequence("Shortcuts/Editor/", clearSelectionsAction);
     connect(clearSelectionsAction, SIGNAL(triggered()), this, SLOT(clearSelections()));
     ui.listView->addAction(clearSelectionsAction);
 
     c2bUtils::addSeparator(ui.listView);
     refreshListAction = new QAction(this);
     refreshListAction->setShortcut(QKeySequence(QKeySequence::Refresh));
-    refreshListAction->setText(tr("Refresh List and Browser View"));
-    refreshListAction->setStatusTip(tr("Refresh List and Browser View"));
+    refreshListAction->setText(tr("Refresh List and Browser"));
+    refreshListAction->setStatusTip(tr("Refresh list and browser"));
     connect(refreshListAction, SIGNAL(triggered()), this, SLOT(refreshList()));
     ui.listView->addAction(refreshListAction);
     connect(ui.listView, SIGNAL(itemActivated(QTreeWidgetItem*, int)), this, SLOT(goToReference(QTreeWidgetItem*)));
@@ -142,14 +148,16 @@ c2bReferenceList::c2bReferenceList(c2bTextEdit* ed, c2bTextBrowser* br, QWidget*
     _browserP->document()->setDefaultStyleSheet(references_css);
 
     openTextLocalSearchAction = new QAction(this);
-    openTextLocalSearchAction->setText(tr("Local Search for selected text"));
-    openTextLocalSearchAction->setStatusTip(tr("Local Search for selected text"));
+    openTextLocalSearchAction->setText(tr("Local Search for Selected Text"));
+    openTextLocalSearchAction->setStatusTip(tr("Local search for selected text"));
+    _settingsP->setKeysequence("Shortcuts/Editor/", openTextLocalSearchAction);
     connect(openTextLocalSearchAction, SIGNAL(triggered()), this, SLOT(openTextLocalSearch()));
     openTextLocalSearchAction->setEnabled(false);
     connect(_browserP, SIGNAL(copyAvailable(bool)), openTextLocalSearchAction, SLOT(setEnabled(bool)));
     openTextWebSearchAction = new QAction(this);
-    openTextWebSearchAction->setText(tr("Web Search for selected text"));
-    openTextWebSearchAction->setStatusTip(tr("Web Search for selected text"));
+    openTextWebSearchAction->setText(tr("Web Search for Selected Text"));
+    openTextWebSearchAction->setStatusTip(tr("Web search for selected text"));
+    _settingsP->setKeysequence("Shortcuts/Editor/", openTextWebSearchAction);
     connect(openTextWebSearchAction, SIGNAL(triggered()), this, SLOT(openTextWebSearch()));
     openTextWebSearchAction->setEnabled(false);
     connect(_browserP, SIGNAL(copyAvailable(bool)), openTextWebSearchAction, SLOT(setEnabled(bool)));
@@ -361,7 +369,7 @@ void c2bReferenceList::openUrl()
         ++it;
     }
     if (!zurl)
-        c2b::showMessage(tr("No Url entry among selected references."));
+        c2b::showMessage(tr("No URL entry among selected references."));
 }
 
 void c2bReferenceList::openLink(const QUrl& ln)
@@ -558,17 +566,17 @@ void c2bReferenceList::itemSelectionChanged()
         ++it;
     }
     citeEntryAction->setEnabled(entries > 0);
-    citeEntryAction->setStatusTip(tr("Cite Selected Entries. %1 Entries selected.").arg(entries));
+    citeEntryAction->setStatusTip(tr("Cite selected entries. %1 Entries selected.").arg(entries));
     openDOIAction->setEnabled(doi > 0);
-    openDOIAction->setStatusTip(tr("Browse Reference by DOI. %1 DOIs in selected entries.").arg(doi));
+    openDOIAction->setStatusTip(tr("Browse reference by DOI. %1 DOIs in selected entries.").arg(doi));
     openFileAction->setEnabled(file > 0);
-    openFileAction->setStatusTip(tr("Open Document File. %1 Files in selected entries.").arg(file));
+    openFileAction->setStatusTip(tr("Open document file. %1 Files in selected entries.").arg(file));
     openUrlAction->setEnabled(url > 0);
-    openUrlAction->setStatusTip(tr("Open Document Url. %1 Urls in selected entries.").arg(url));
+    openUrlAction->setStatusTip(tr("Open document URL. %1 URLs in selected entries.").arg(url));
     openAuthorsWebSearchAction->setEnabled(author > 0);
-    openAuthorsWebSearchAction->setStatusTip(tr("Web Search by Authors. %1 Entries selected.").arg(author));
+    openAuthorsWebSearchAction->setStatusTip(tr("Web search by Author. %1 Entries selected.").arg(author));
     openTitleWebSearchAction->setEnabled(title > 0);
-    openTitleWebSearchAction->setStatusTip(tr("Web Search by Title. %1 Entries selected.").arg(title));
+    openTitleWebSearchAction->setStatusTip(tr("Web search by Title. %1 Entries selected.").arg(title));
     emit hasSelectedItems(entries > 0);
 }
 
