@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2011 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.5. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bSaveRegExp.h"
@@ -14,7 +14,7 @@
 #include <QPushButton>
 
 
-/** \page regexpedit The Regular Expression Editor
+/** \page regexpedit Regular Expression Editor
 
     Once a manual processing is done, cb2Bib clipboard area contains the
     extraction tags, plus, possibly, some other cb2Bib tags introduced during
@@ -66,7 +66,7 @@ target="_blank">http://doc.trolltech.com/4.5/qregexp.html#introduction</a>.
     expression file. Patterns are reloaded each time the automatic pattern
     recognition is started. This permits editing and testing.
 
-    - The cb2bib processes sequentially the list of regular expressions as
+    - The cb2Bib processes sequentially the list of regular expressions as
     found in the regular expression file. It stops and picks the first match
     for the current input. <b>Therefore, the order of the regular expressions
     is important</b>. Consequently, to avoid possible clashing among similar
