@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2011 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.5. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #define C2B_CHECK_CAPITALIZATION 0
@@ -628,6 +628,14 @@ void c2bTests::heuristic_pvny()
     heuristic(bp, reference, "Science 120(1 - 3), 927 - 993");
     heuristic(bp, reference, "Science 120(1 - 3), pp. 927 - 993");
 
+    reference.clearReference();
+    reference.insert("journal", bp.parse("journal", "Science"));
+    reference.insert("pages", bp.parse("pages", "927 - 993"));
+    reference.insert("volume", bp.parse("volume", "120"));
+    reference.insert("number", bp.parse("number", "1"));
+    write(bp, reference);
+    heuristic(bp, reference, "Science, Volume 120, Number 1, 927 - 993");
+
     /****************************************************************
     journal-pages-volume-year
     ****************************************************************/
@@ -737,6 +745,8 @@ void c2bTests::heuristic_pvny()
     heuristic(bp, reference, "Science 2007 January 25; 120(1), 117");
     heuristic(bp, reference, "Science 2007 January 25 120(1), 117");
     heuristic(bp, reference, "Science 2007 May 25 120(1), 117");
+    heuristic(bp, reference, "Science (2007), 120, 1, 117");
+    heuristic(bp, reference, "Science, Vol. 120, No. 1 (2007) 117");
 
     reference.clearReference();
     reference.insert("journal", bp.parse("journal", "Science"));
@@ -755,6 +765,7 @@ void c2bTests::heuristic_pvny()
     heuristic(bp, reference, "Science. 2007, 120(1), 10 - 17");
     heuristic(bp, reference, "Science. 2007, 120(1), pp 10 - 17");
     heuristic(bp, reference, "Science. 2007 January 25, 120(1), pp 10 - 17");
+    heuristic(bp, reference, "Science (2007), 120, 1, pp. 10-17");
 
     reference.clearReference();
     reference.insert("journal", bp.parse("journal", "Science"));
@@ -801,6 +812,7 @@ void c2bTests::heuristic_pvny()
     heuristic(bp, reference, "Science 2007, 120(1), 1922");
     heuristic(bp, reference, "Science 2007 120(1): 1922");
     heuristic(bp, reference, "Science 2007 May 25 120(1): 1922");
+    heuristic(bp, reference, "Science, Vol. 120, No. 1 (2007) 1922");
 
     reference.clearReference();
     reference.insert("journal", bp.parse("journal", "Science"));
@@ -819,6 +831,8 @@ void c2bTests::heuristic_pvny()
     heuristic(bp, reference, "Science. 2007, 120(1), 1922 - 1927");
     heuristic(bp, reference, "Science. 2007, 120(1), pp 1922 - 1927");
     heuristic(bp, reference, "Science. 2007 May 25, 120(1), pp 1922 - 1927");
+    heuristic(bp, reference, "Science (2007), 120, 1, pp. 1922-1927");
+    heuristic(bp, reference, "Science, Vol. 120, No. 1 (2007) 1922 - 1927");
 
     reference.clearReference();
     reference.insert("journal", bp.parse("journal", "Science"));
