@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2011 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.5. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bTextEdit.h"
@@ -9,51 +9,42 @@
 #include "c2bSettings.h"
 #include "c2bUtils.h"
 
-#include <QKeyEvent>
-#include <QList>
 #include <QMenu>
 #include <QPainter>
 #include <QScrollBar>
 #include <QTextBlock>
-#include <QTextCursor>
 
 
 c2bTextEdit::c2bTextEdit(QWidget* parentw) : QPlainTextEdit(parentw)
 {
     setFrameShape(QPlainTextEdit::StyledPanel);
     setFrameShadow(QPlainTextEdit::Raised);
-    settings = c2bSettingsP;
-    connect(settings, SIGNAL(newSettings()), this, SLOT(loadSettings()));
+    _settingsP = c2bSettingsP;
+    connect(_settingsP, SIGNAL(newSettings()), this, SLOT(loadSettings()));
 
     _line_number_area = new LineNumberArea(this);
     _line_number_area_color = palette().color(QPalette::Active, QPalette::Base).darker(110);
-    _line_number_color_p = &settings->colors.comment_color;
+    _line_number_color_p = &_settingsP->colors.comment_color;
     connect(this, SIGNAL(blockCountChanged(int)), this, SLOT(updateLineNumberAreaWidth()));
     connect(this, SIGNAL(updateRequest(const QRect&, int)), this, SLOT(updateLineNumberArea(const QRect&, int)));
     updateLineNumberAreaWidth();
 
     c2bUtils::addSeparator(this);
-    wordWrapAction = new QAction(this);
-    addAction(wordWrapAction);
-    wordWrapAction->setText(tr("Wrap Text"));
-    wordWrapAction->setStatusTip(tr("Wrap Text"));
-    connect(wordWrapAction, SIGNAL(triggered()), this, SLOT(wordWrap()));
-
-    wordUnWrapAction = new QAction(this);
-    addAction(wordUnWrapAction);
-    wordUnWrapAction->setText(tr("Unwrap Text"));
-    wordUnWrapAction->setStatusTip(tr("Unwrap Text"));
-    connect(wordUnWrapAction, SIGNAL(triggered()), this, SLOT(wordUnWrap()));
-
-    if (settings->value("c2bTextEdit/WrapMode", false).toBool())
-        wordWrap();
+    toggleWordWrappingAction = new QAction(this);
+    addAction(toggleWordWrappingAction);
+    toggleWordWrappingAction->setText(tr("Toggle Word Wrapping"));
+    toggleWordWrappingAction->setStatusTip(tr("Toggle word wrapping"));
+    _settingsP->setKeysequence("Shortcuts/Editor/", toggleWordWrappingAction);
+    connect(toggleWordWrappingAction, SIGNAL(triggered()), this, SLOT(toggleWordWrapping()));
+    if (_settingsP->value("c2bTextEdit/WrapMode", false).toBool())
+        setLineWrapMode(QPlainTextEdit::WidgetWidth);
     else
-        wordUnWrap();
+        setLineWrapMode(QPlainTextEdit::NoWrap);
 }
 
 c2bTextEdit::~c2bTextEdit()
 {
-    settings->setValue("c2bTextEdit/WrapMode", lineWrapMode() == QPlainTextEdit::WidgetWidth);
+    _settingsP->setValue("c2bTextEdit/WrapMode", lineWrapMode() == QPlainTextEdit::WidgetWidth);
 }
 
 
@@ -62,22 +53,24 @@ void c2bTextEdit::setBibTeXActions()
     c2bUtils::addSeparator(this);
     pasteCurrentBibTeXAction = new QAction(this);
     addAction(pasteCurrentBibTeXAction);
-    pasteCurrentBibTeXAction->setShortcut(tr("Shift+Ins"));
     pasteCurrentBibTeXAction->setText(tr("Paste Current BibTeX"));
-    pasteCurrentBibTeXAction->setStatusTip(tr("Paste Current BibTeX"));
+    pasteCurrentBibTeXAction->setStatusTip(tr("Paste current BibTeX"));
+    _settingsP->setKeysequence("Shortcuts/Editor/", pasteCurrentBibTeXAction);
 
     c2bUtils::addSeparator(this);
     convertSelection2LaTeXAction = new QAction(this);
     addAction(convertSelection2LaTeXAction);
     convertSelection2LaTeXAction->setText(tr("Selection to LaTeX"));
-    convertSelection2LaTeXAction->setStatusTip(tr("Selection to LaTeX"));
+    convertSelection2LaTeXAction->setStatusTip(tr("Convert selection to LaTeX"));
+    _settingsP->setKeysequence("Shortcuts/Editor/", convertSelection2LaTeXAction);
     connect(convertSelection2LaTeXAction, SIGNAL(triggered()), this, SLOT(convert2LaTeX()));
     convertSelection2LaTeXAction->setEnabled(false);
     connect(this, SIGNAL(copyAvailable(bool)), convertSelection2LaTeXAction, SLOT(setEnabled(bool)));
     convertSelection2UnicodeAction = new QAction(this);
     addAction(convertSelection2UnicodeAction);
     convertSelection2UnicodeAction->setText(tr("Selection to Unicode"));
-    convertSelection2UnicodeAction->setStatusTip(tr("Selection to Unicode"));
+    convertSelection2UnicodeAction->setStatusTip(tr("Convert selection to Unicode"));
+    _settingsP->setKeysequence("Shortcuts/Editor/", convertSelection2UnicodeAction);
     connect(convertSelection2UnicodeAction, SIGNAL(triggered()), this, SLOT(convert2Unicode()));
     convertSelection2UnicodeAction->setEnabled(false);
     connect(this, SIGNAL(copyAvailable(bool)), convertSelection2UnicodeAction, SLOT(setEnabled(bool)));
@@ -86,17 +79,20 @@ void c2bTextEdit::setBibTeXActions()
     journalsToFullAction = new QAction(this);
     addAction(journalsToFullAction);
     journalsToFullAction->setText(tr("Set Journals to Full Name"));
-    journalsToFullAction->setStatusTip(tr("Set Journals to Full Name"));
+    journalsToFullAction->setStatusTip(tr("Set journals to full name"));
+    _settingsP->setKeysequence("Shortcuts/Editor/", journalsToFullAction);
     journalsToAbbreviatedAction = new QAction(this);
     addAction(journalsToAbbreviatedAction);
     journalsToAbbreviatedAction->setText(tr("Set Journals to Abbreviated Name"));
-    journalsToAbbreviatedAction->setStatusTip(tr("Set Journals to Abbreviated Name"));
+    journalsToAbbreviatedAction->setStatusTip(tr("Set journals to abbreviated name"));
+    _settingsP->setKeysequence("Shortcuts/Editor/", journalsToAbbreviatedAction);
 
     c2bUtils::addSeparator(this);
     updateMetadataAction = new QAction(this);
     addAction(updateMetadataAction);
     updateMetadataAction->setText(tr("Update Documents Metadata"));
-    updateMetadataAction->setStatusTip(tr("Update Documents Metadata"));
+    updateMetadataAction->setStatusTip(tr("Update document files metadata"));
+    _settingsP->setKeysequence("Shortcuts/Editor/", updateMetadataAction);
 }
 
 void c2bTextEdit::contextMenuEvent(QContextMenuEvent* qevent)
@@ -119,18 +115,12 @@ void c2bTextEdit::keyPressEvent(QKeyEvent* qevent)
     }
 }
 
-void c2bTextEdit::wordWrap()
+void c2bTextEdit::toggleWordWrapping()
 {
-    setLineWrapMode(QPlainTextEdit::WidgetWidth);
-    wordWrapAction->setEnabled(false);
-    wordUnWrapAction->setEnabled(true);
-}
-
-void c2bTextEdit::wordUnWrap()
-{
-    setLineWrapMode(QPlainTextEdit::NoWrap);
-    wordWrapAction->setEnabled(true);
-    wordUnWrapAction->setEnabled(false);
+    if (lineWrapMode() == QPlainTextEdit::WidgetWidth)
+        setLineWrapMode(QPlainTextEdit::NoWrap);
+    else
+        setLineWrapMode(QPlainTextEdit::WidgetWidth);
 }
 
 void c2bTextEdit::updatePlainText(const QString& newText)
@@ -175,9 +165,9 @@ void c2bTextEdit::convert2Unicode()
 
 void c2bTextEdit::loadSettings()
 {
-    if (font() != settings->c2bMonoFont)
+    if (font() != _settingsP->c2bMonoFont)
     {
-        setFont(settings->c2bMonoFont);
+        setFont(_settingsP->c2bMonoFont);
         updateLineNumberAreaWidth();
     }
     _line_number_area->update(); // Update, otherwise number colors might not follow apply button
