@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2011 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.5. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BTEXTEDIT_H
@@ -10,8 +10,6 @@
 #include <QPlainTextEdit>
 
 
-class QAction;
-class QMenu;
 class c2bSettings;
 
 
@@ -29,9 +27,8 @@ public:
     QAction* journalsToAbbreviatedAction;
     QAction* journalsToFullAction;
     QAction* pasteCurrentBibTeXAction;
+    QAction* toggleWordWrappingAction;
     QAction* updateMetadataAction;
-    QAction* wordUnWrapAction;
-    QAction* wordWrapAction;
     void setBibTeXActions();
     void updatePlainText(const QString& text);
 
@@ -51,8 +48,7 @@ signals:
 
 
 public slots:
-    void wordUnWrap();
-    void wordWrap();
+    void toggleWordWrapping();
 
 
 protected slots:
@@ -71,7 +67,7 @@ private:
     QColor* _line_number_color_p;
     QString _editor_filename;
     QWidget* _line_number_area;
-    c2bSettings* settings;
+    c2bSettings* _settingsP;
     int lineNumberAreaWidth();
     void lineNumberAreaPaintEvent(QPaintEvent* qevent);
 
