@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2011 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.5. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bUtils.h"
@@ -15,14 +15,14 @@ namespace c2bUtils
 
 bool openFile(const QString& fn, QWidget* w)
 {
-    // Url fn is decoded always, in the hope of making openFile encoding agnostic
+    // URL fn is decoded always, in the hope of making openFile encoding agnostic
     const QString decoded(QUrl::fromPercentEncoding(fn.toUtf8()));
     const QUrl url(stringToUrl(decoded));
     if (!url.isValid())
     {
         if (w)
             QMessageBox::warning(w, QObject::tr("Warning - cb2Bib"),
-                                 QObject::tr("Unable to open file.\nError: Url '%1' is not valid.").
+                                 QObject::tr("Unable to open file.\nError: URL '%1' is not valid.").
                                  arg(url.toString()), QMessageBox::Ok);
         return false;
     }
