@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2011 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.5. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "cb2Bib.h"
@@ -211,7 +211,10 @@
 
 \subsection keyboard Additional, Keyboard Functionality
 
-    - <b>Alt A</b> \n Open cb2Bib Annote. Specify the note's filename in the
+    Most keyboard shortcuts are customizable. See \ref c2bconf_shortcuts. In
+    the following, default shortcuts are used to describe functionality.
+
+    - <b>Alt A</b> \n Starts cb2Bib Annote. Specify the note's filename in the
     dialog. A new note is created if the file name does not exist. The cb2Bib
     Annote is opened as a separate program. Exiting cb2Bib will not exit the
     note's viewer. On the viewer, pressing key E launches the default text
@@ -293,6 +296,8 @@
     \endhtmlonly
     search pattern. See also \ref c2bconf_bibtex.
 
+    - <b>F4</b> \n Toggles between Main and Other Fields reference edit tabs.
+
     - <b>Esc</b> \n Quits cb2Bib popup menu. The cb2Bib menu pops up each time
     a selection in made in the clipboard panel. This saves keystrokes in a
     normal bibliographic extraction. Press <b>Esc</b> or <b>Right Click</b>
@@ -820,7 +825,7 @@
     MacOSX platforms.
 
     First, if you encounter a 'nothing to install'-error during installation on
-    MacOSX 10.4.x using the cb2bib binary installer available at
+    MacOSX 10.4.x using the cb2Bib binary installer available at
     \htmlonly
     <a href="http://naranja.umh.es/~atg/" target="_blank">http://naranja.umh.es/~atg/</a>,
     \endhtmlonly
@@ -1062,36 +1067,55 @@ cb2Bib::cb2Bib(QWidget* parentw) : QMainWindow(parentw)
     // Actions and shortcuts
     c2bUtils::addSeparator(this);
     addAction(ui.checkRepeatedAction);
+    _settingsP->setKeysequence("Shortcuts/cb2Bib/", ui.checkRepeatedAction);
     c2bUtils::addSeparator(this);
     addAction(ui.clearFieldsAction);
+    _settingsP->setKeysequence("Shortcuts/cb2Bib/", ui.clearFieldsAction);
     addAction(ui.guessFieldsAction);
+    _settingsP->setKeysequence("Shortcuts/cb2Bib/", ui.guessFieldsAction);
     addAction(ui.startEngineAction);
+    _settingsP->setKeysequence("Shortcuts/cb2Bib/", ui.startEngineAction);
     c2bUtils::addSeparator(this);
     addAction(ui.preparseClipboardAction);
+    _settingsP->setKeysequence("Shortcuts/cb2Bib/", ui.preparseClipboardAction);
     addAction(ui.postprocessBibTeXAction);
+    _settingsP->setKeysequence("Shortcuts/cb2Bib/", ui.postprocessBibTeXAction);
     c2bUtils::addSeparator(this);
     addAction(ui.editBookmarksAction);
+    _settingsP->setKeysequence("Shortcuts/cb2Bib/", ui.editBookmarksAction);
     addAction(ui.editAbbreviationsAction);
+    _settingsP->setKeysequence("Shortcuts/cb2Bib/", ui.editAbbreviationsAction);
     addAction(ui.editRegExpsAction);
+    _settingsP->setKeysequence("Shortcuts/cb2Bib/", ui.editRegExpsAction);
     c2bUtils::addSeparator(this);
     addAction(ui.openAnnoteAction);
+    _settingsP->setKeysequence("Shortcuts/cb2Bib/", ui.openAnnoteAction);
 #ifndef C2B_USE_WEBKIT
     ui.openAnnoteAction->setDisabled(true);
 #endif
     c2bUtils::addSeparator(this);
     addAction(ui.insertRegExpAction);
+    _settingsP->setKeysequence("Shortcuts/cb2Bib/", ui.insertRegExpAction);
     addAction(ui.viewTaggedClipEditAction);
+    _settingsP->setKeysequence("Shortcuts/cb2Bib/", ui.viewTaggedClipEditAction);
     setAcceptDrops(true);
 
     c2bUtils::addSeparator(ui.file);
     ui.file->addAction(ui.selectFileAction);
+    _settingsP->setKeysequence("Shortcuts/cb2Bib/", ui.selectFileAction);
     ui.file->addAction(ui.openFileDocumentAction);
+    _settingsP->setKeysequence("Shortcuts/cb2Bib/", ui.openFileDocumentAction);
     ui.openFileDocumentAction->setEnabled(false);
 
-    QShortcut* sc = new QShortcut(QKeySequence(Qt::ALT + Qt::Key_D), this);
+    QShortcut* sc(new QShortcut(this));
+    _settingsP->setKeysequence("Shortcuts/cb2Bib/Delete Temporary BibTeX File", sc);
     connect(sc, SIGNAL(activated()), this, SLOT(deleteTmpBib()));
-    sc = new QShortcut(QKeySequence(Qt::ALT + Qt::Key_W), this);
+    sc = new QShortcut(this);
+    _settingsP->setKeysequence("Shortcuts/cb2Bib/Write Metadata to Document", sc);
     connect(sc, SIGNAL(activated()), this, SLOT(addMetadata()));
+    sc = new QShortcut(this);
+    _settingsP->setKeysequence("Shortcuts/cb2Bib/Toggle Reference Tabs", sc);
+    connect(sc, SIGNAL(activated()), this, SLOT(toggleReferenceTabs()));
     sc = new QShortcut(QKeySequence(Qt::Key_F2), this); // Made consistent with c2bCiter and c2bEditor
     connect(sc, SIGNAL(activated()), this, SLOT(hide()));
 
@@ -1152,7 +1176,7 @@ cb2Bib::cb2Bib(QWidget* parentw) : QMainWindow(parentw)
     _bpP = c2b::bibParser();
     setWidgetMapping();
     _modified = false;
-    ui.addBibB->setEnabled(_modified);
+    ui.AddBibB->setEnabled(_modified);
 
     // Setting cb2bib network queries
     _netQP = new c2bNetworkQuery(_bpP, c2b::net(), this);
@@ -1175,7 +1199,7 @@ cb2Bib::cb2Bib(QWidget* parentw) : QMainWindow(parentw)
     c2bClipboard* cbP = c2b::clipboard();
     connect(cbP, SIGNAL(cbDataChanged(const QString&)), this, SLOT(dataChanged(const QString&)));
     _connected = false;
-    on_connectB_clicked(); // Set button and update _connected
+    on_ConnectB_clicked(); // Set button and update _connected
     dataChanged(cbP->text());
     if (_settingsP->cl_bibedit)
         initAsBibTeXEditor();
@@ -1202,7 +1226,7 @@ void cb2Bib::show()
         QMainWindow::show();
 }
 
-void cb2Bib::on_viewAboutB_clicked()
+void cb2Bib::on_ViewAboutB_clicked()
 {
     if (ui.stackedWidget->currentWidget() == AboutBrowser)
     {
@@ -1229,21 +1253,22 @@ void cb2Bib::on_viewAboutB_clicked()
                 "<thead><tr>"
                 "<th>Keys</th><th>Description</th></tr>"
                 "</thead><tbody><tr>"
-                "<td>Alt A</td><td>Open cb2Bib Annote</td></tr><tr>"
-                "<td>Alt B</td><td>Edit bookmarks</td></tr><tr>"
-                "<td>Alt C</td><td>Preparses cb2Bib's clipboard</td></tr><tr>"
-                "<td>Alt D</td><td>Deletes temporary BibTeX file</td></tr><tr>"
-                "<td>Alt E</td><td>Edit regular expressions</td></tr><tr>"
-                "<td>Alt F</td><td>Select source document filename</td></tr><tr>"
-                "<td>Alt I</td><td>Insert regular expression</td></tr><tr>"
-                "<td>Alt J</td><td>Edit journal abbreviations</td></tr><tr>"
-                "<td>Alt O</td><td>Open source document</td></tr><tr>"
-                "<td>Alt P</td><td>Postprocess BibTeX</td></tr><tr>"
-                "<td>Alt R</td><td>Restarts automatic recognition</td></tr><tr>"
-                "<td>Alt W</td><td>Writes metadata to source document</td></tr><tr>"
-                "<td>Alt X</td><td>Check repeated</td></tr><tr>"
-                "<td>Esc</td><td>Quits cb2Bib popup menu</td></tr><tr>"
-                "<td>Right Click</td><td>Editor's popup menu"
+                "<td>" + _settingsP->ksname("Shortcuts/cb2Bib/Check Repeated") + "</td><td>Check repeated</td></tr><tr>"
+                "<td>" + _settingsP->ksname("Shortcuts/cb2Bib/Delete Temporary BibTeX File") + "</td><td>Delete temporary BibTeX file</td></tr><tr>"
+                "<td>" + _settingsP->ksname("Shortcuts/cb2Bib/Edit Bookmarks") + "</td><td>Edit bookmarks</td></tr><tr>"
+                "<td>" + _settingsP->ksname("Shortcuts/cb2Bib/Edit Journal Abbreviations") + "</td><td>Edit journal abbreviations</td></tr><tr>"
+                "<td>" + _settingsP->ksname("Shortcuts/cb2Bib/Edit Regular Expressions") + "</td><td>Edit regular expressions</td></tr><tr>"
+                "<td>" + _settingsP->ksname("Shortcuts/cb2Bib/Insert Regular Expression") + "</td><td>Insert regular expression</td></tr><tr>"
+                "<td>" + _settingsP->ksname("Shortcuts/cb2Bib/Open Document") + "</td><td>Open document</td></tr><tr>"
+                "<td>" + _settingsP->ksname("Shortcuts/cb2Bib/Postprocess BibTeX") + "</td><td>Postprocess BibTeX</td></tr><tr>"
+                "<td>" + _settingsP->ksname("Shortcuts/cb2Bib/Preparse Clipboard") + "</td><td>Preparse clipboard</td></tr><tr>"
+                "<td>" + _settingsP->ksname("Shortcuts/cb2Bib/Restart Recognition") + "</td><td>Restart recognition</td></tr><tr>"
+                "<td>" + _settingsP->ksname("Shortcuts/cb2Bib/Select Document File") + "</td><td>Select document file</td></tr><tr>"
+                "<td>" + _settingsP->ksname("Shortcuts/cb2Bib/Start Annote") + "</td><td>Open cb2Bib Annote</td></tr><tr>"
+                "<td>" + _settingsP->ksname("Shortcuts/cb2Bib/Toggle Reference Tabs") + "</td><td>Toggle reference tabs</td></tr><tr>"
+                "<td>" + _settingsP->ksname("Shortcuts/cb2Bib/Write Metadata to Document") + "</td><td>Write metadata to document</td></tr><tr>"
+                "<td>Esc</td><td>Quit cb2Bib popup menu</td></tr><tr>"
+                "<td>Right Click</td><td>Show cb2Bib main panel popup menu"
                 "</td></tr></tbody>"
                 "</table>"
                 "<br /> %2 <br />"
@@ -1264,12 +1289,12 @@ void cb2Bib::on_viewAboutB_clicked()
     updateViewButtons();
 }
 
-void cb2Bib::on_configureB_clicked()
+void cb2Bib::on_ConfigureB_clicked()
 {
     c2b::configure();
 }
 
-void cb2Bib::on_searchInFilesB_clicked()
+void cb2Bib::on_SearchInFilesB_clicked()
 {
     doSearchInFiles();
 }
@@ -1284,40 +1309,40 @@ void cb2Bib::on_PdfImportB_clicked()
         connect(this, SIGNAL(endedProcessing(bool)), _pdfImportP, SLOT(referenceExtacted(bool)));
         connect(_pdfImportP, SIGNAL(textProcessed(const QString&)), this, SLOT(forceDataChange(const QString&)));
         connect(_pdfImportP, SIGNAL(fileProcessed(const QString&)), this, SLOT(fileDropped(const QString&)));
-        connect(_pdfImportP, SIGNAL(saveReferenceRequest()), this, SLOT(on_addBibB_clicked()));
-        connect(_pdfImportP, SIGNAL(setClipboardDisabled(bool)), ui.connectB, SLOT(setDisabled(bool)));
+        connect(_pdfImportP, SIGNAL(saveReferenceRequest()), this, SLOT(on_AddBibB_clicked()));
+        connect(_pdfImportP, SIGNAL(setClipboardDisabled(bool)), ui.ConnectB, SLOT(setDisabled(bool)));
         showMessage(tr("PDF Import launched."));
     }
     _pdfImportP->show();
 }
 
-void cb2Bib::on_exitB_clicked()
+void cb2Bib::on_ExitB_clicked()
 {
     c2b::instance()->exitRequested();
 }
 
-void cb2Bib::on_connectB_clicked()
+void cb2Bib::on_ConnectB_clicked()
 {
     if (_connected)
     {
-        ui.connectB->setIcon(QIcon(C2B_ICON_DIR + C2B_ICON_DISCONNECT_B));
-        ui.connectB->setStatusTip(tr("Connect clipboard"));
+        ui.ConnectB->setIcon(QIcon(C2B_ICON_DIR + C2B_ICON_DISCONNECT_B));
+        ui.ConnectB->setStatusTip(buttonStatusTip(tr("Connect clipboard"), ui.ConnectB->shortcut()));
         _connected = false;
     }
     else
     {
-        ui.connectB->setIcon(QIcon(C2B_ICON_DIR + C2B_ICON_CONNECT_B));
-        ui.connectB->setStatusTip(tr("Disconnect clipboard"));
+        ui.ConnectB->setIcon(QIcon(C2B_ICON_DIR + C2B_ICON_CONNECT_B));
+        ui.ConnectB->setStatusTip(buttonStatusTip(tr("Disconnect clipboard"), ui.ConnectB->shortcut()));
         _connected = true;
     }
 }
 
-void cb2Bib::on_makeNetworkQueryB_clicked()
+void cb2Bib::on_MakeNetworkQueryB_clicked()
 {
     makeNetQuery();
 }
 
-void cb2Bib::on_viewBibB_clicked()
+void cb2Bib::on_ViewBibB_clicked()
 {
     if (ui.stackedWidget->currentWidget() == BibBrowser)
     {
@@ -1333,16 +1358,16 @@ void cb2Bib::on_viewBibB_clicked()
     updateViewButtons();
 }
 
-void cb2Bib::on_addBibB_clicked()
+void cb2Bib::on_AddBibB_clicked()
 {
     // Prepare Save Reference to file
-    ui.addBibB->setEnabled(false);
+    ui.AddBibB->setEnabled(false);
     if (!_is_check_repeated_done && _settingsP->value("cb2Bib/CheckRepeatedOnSave").toBool())
     {
         _is_check_repeated_done = true;
         if (isReferenceRepeated())
         {
-            ui.addBibB->setEnabled(_modified);
+            ui.AddBibB->setEnabled(_modified);
             return;
         }
     }
@@ -1356,7 +1381,7 @@ void cb2Bib::on_addBibB_clicked()
     {
         QMessageBox::information(this, tr("Information - cb2Bib"), tr("Unable to open file %1 for writing.\nError: '%2'.").
                                  arg(ui.bibtexfile->currentText()).arg(bibtexfile.errorString()), QMessageBox::Ok);
-        ui.addBibB->setEnabled(_modified);
+        ui.AddBibB->setEnabled(_modified);
         return;
     }
     if (_dropped_document_file.isEmpty() || ui.file->text().isEmpty() || !_settingsP->value("cb2Bib/MovePdf").toBool())
@@ -1375,7 +1400,7 @@ void cb2Bib::on_addBibB_clicked()
             {
                 QMessageBox::information(this, tr("Information - cb2Bib"),
                                          tr("Unable to create directory %1.").arg(doc_dir_name), QMessageBox::Ok);
-                ui.addBibB->setEnabled(_modified);
+                ui.AddBibB->setEnabled(_modified);
                 return;
             }
         const network::Action CopyMovePdf(network::actionType(_settingsP->value("cb2Bib/CopyMovePdf").toString()));
@@ -1383,12 +1408,12 @@ void cb2Bib::on_addBibB_clicked()
     }
 }
 
-void cb2Bib::on_editBibTeXB_clicked()
+void cb2Bib::on_EditBibTeXB_clicked()
 {
     bibEditor(ui.bibtexfile->currentText());
 }
 
-void cb2Bib::on_file_dirs_clicked()
+void cb2Bib::on_BibTeXDir_clicked()
 {
     const QString fn(c2bFileDialog::getFilename(this, "Select a BibTeX filename", ui.bibtexfile->currentText(),
                      "BibTeX (*.bib);;All (*)"));
@@ -1401,6 +1426,72 @@ void cb2Bib::loadSettings()
     ClipEdit->setFont(_settingsP->c2bMonoFont);
     BibBrowser->setFont(_settingsP->c2bMonoFont);
     AboutBrowser->setFont(_settingsP->c2bMonoFont);
+
+    ui.AddBibB->setShortcut(QKeySequence::Save);
+    ui.EditBibTeXB->setShortcut(QKeySequence::Open);
+    ui.ExitB->setShortcut(QKeySequence::Quit);
+    ui.SearchInFilesB->setShortcut(QKeySequence::Find);
+
+    ui.BibTeXDir->setShortcut(_settingsP->keysequence("Shortcuts/cb2Bib/Select BibTeX File"));
+    ui.ConfigureB->setShortcut(_settingsP->keysequence("Shortcuts/cb2Bib/Button Configure"));
+    ui.ConnectB->setShortcut(_settingsP->keysequence("Shortcuts/cb2Bib/Button Toggle Connection"));
+    ui.MakeNetworkQueryB->setShortcut(_settingsP->keysequence("Shortcuts/cb2Bib/Button Network Query"));
+    ui.PdfImportB->setShortcut(_settingsP->keysequence("Shortcuts/cb2Bib/Button Start PDFImport"));
+    ui.ViewAboutB->setShortcut(_settingsP->keysequence("Shortcuts/cb2Bib/Button About and Bookmarks"));
+    ui.ViewBibB->setShortcut(_settingsP->keysequence("Shortcuts/cb2Bib/Button View BibTeX"));
+
+    ui.AddBibB->setStatusTip(buttonStatusTip(tr("Save reference to BibTeX file"), ui.AddBibB->shortcut()));
+    ui.BibTeXDir->setStatusTip(buttonStatusTip(tr("Select BibTeX file"), ui.BibTeXDir->shortcut()));
+    ui.ConfigureB->setStatusTip(buttonStatusTip(tr("Configure cb2Bib"), ui.ConfigureB->shortcut()));
+    ui.ConnectB->setStatusTip(buttonStatusTip(_connected ? tr("Disconnect clipboard") : tr("Connect clipboard"), ui.ConnectB->shortcut()));
+    ui.EditBibTeXB->setStatusTip(buttonStatusTip(tr("Open BibTeX file"), ui.EditBibTeXB->shortcut()));
+    ui.ExitB->setStatusTip(buttonStatusTip(tr("Close all windows and exit"), ui.ExitB->shortcut()));
+    ui.MakeNetworkQueryB->setStatusTip(buttonStatusTip(tr("Network query for current reference"), ui.MakeNetworkQueryB->shortcut()));
+    ui.PdfImportB->setStatusTip(buttonStatusTip(tr("Import references from a set of PDF files"), ui.PdfImportB->shortcut()));
+    ui.SearchInFilesB->setStatusTip(buttonStatusTip(tr("Search BibTeX file for references"), ui.SearchInFilesB->shortcut()));
+    updateViewButtons();
+}
+
+QString cb2Bib::buttonStatusTip(const QString& ms, const QKeySequence& ks) const
+{
+    if (ks.isEmpty())
+        return ms;
+    else
+        return ms + QLatin1String("  -  ") + ks.toString(QKeySequence::NativeText);
+}
+
+void cb2Bib::updateViewButtons()
+{
+    QWidget* viewing = ui.stackedWidget->currentWidget();
+    if (viewing == BibBrowser)
+    {
+        ui.ViewBibB->setIcon(QIcon(C2B_ICON_DIR + C2B_ICON_VIEWC2B_B));
+        ui.ViewAboutB->setIcon(QIcon(C2B_ICON_DIR + C2B_ICON_ABOUT_B));
+        ui.ViewBibB->setStatusTip(buttonStatusTip(tr("View cb2Bib clipboard"), ui.ViewBibB->shortcut()));
+        ui.ViewAboutB->setStatusTip(buttonStatusTip(tr("About cb2bib and cb2bib bookmarks"), ui.ViewAboutB->shortcut()));
+    }
+    else if (viewing == AboutBrowser)
+    {
+        ui.ViewBibB->setIcon(QIcon(C2B_ICON_DIR + C2B_ICON_VIEWBIB_B));
+        ui.ViewAboutB->setIcon(QIcon(C2B_ICON_DIR + C2B_ICON_ABOUT_B_BACK));
+        ui.ViewBibB->setStatusTip(buttonStatusTip(tr("View BibTeX for current reference"), ui.ViewBibB->shortcut()));
+        ui.ViewAboutB->setStatusTip(buttonStatusTip(tr("Back to cb2Bib clipboard"), ui.ViewAboutB->shortcut()));
+    }
+    else
+    {
+        ui.ViewBibB->setIcon(QIcon(C2B_ICON_DIR + C2B_ICON_VIEWBIB_B));
+        ui.ViewAboutB->setIcon(QIcon(C2B_ICON_DIR + C2B_ICON_ABOUT_B));
+        ui.ViewBibB->setStatusTip(buttonStatusTip(tr("View BibTeX for current reference"), ui.ViewBibB->shortcut()));
+        ui.ViewAboutB->setStatusTip(buttonStatusTip(tr("About cb2bib and cb2bib bookmarks"), ui.ViewAboutB->shortcut()));
+    }
+}
+
+void cb2Bib::toggleReferenceTabs()
+{
+    if (ui.tabWidget->currentIndex() == 0)
+        ui.tabWidget->setCurrentIndex(1);
+    else
+        ui.tabWidget->setCurrentIndex(0);
 }
 
 void cb2Bib::updateBibfile(const QString& fn)
@@ -1418,32 +1509,6 @@ void cb2Bib::updateBibfile(const QString& fn)
         ui.bibtexfile->setCurrentIndex(index);
 }
 
-void cb2Bib::updateViewButtons()
-{
-    QWidget* viewing = ui.stackedWidget->currentWidget();
-    if (viewing == BibBrowser)
-    {
-        ui.viewBibB->setIcon(QIcon(C2B_ICON_DIR + C2B_ICON_VIEWC2B_B));
-        ui.viewAboutB->setIcon(QIcon(C2B_ICON_DIR + C2B_ICON_ABOUT_B));
-        ui.viewBibB->setStatusTip(tr("View cb2Bib clipboard - Alt+V"));
-        ui.viewAboutB->setStatusTip(tr("About cb2bib and cb2bib Bookmarks - Ctrl+Tab"));
-    }
-    else if (viewing == AboutBrowser)
-    {
-        ui.viewBibB->setIcon(QIcon(C2B_ICON_DIR + C2B_ICON_VIEWBIB_B));
-        ui.viewAboutB->setIcon(QIcon(C2B_ICON_DIR + C2B_ICON_ABOUT_B_BACK));
-        ui.viewBibB->setStatusTip(tr("View BibTeX Reference - Ctrl+V"));
-        ui.viewAboutB->setStatusTip(tr("Back to cb2Bib clipboard - Ctrl+Tab"));
-    }
-    else
-    {
-        ui.viewBibB->setIcon(QIcon(C2B_ICON_DIR + C2B_ICON_VIEWBIB_B));
-        ui.viewAboutB->setIcon(QIcon(C2B_ICON_DIR + C2B_ICON_ABOUT_B));
-        ui.viewBibB->setStatusTip(tr("View BibTeX Reference - Alt+V"));
-        ui.viewAboutB->setStatusTip(tr("About cb2bib and cb2bib Bookmarks - Ctrl+Tab"));
-    }
-}
-
 void cb2Bib::showLink(const QString& ln)
 {
     statusBar()->showMessage(c2b::encodeLink(ln), C2B_MESSAGE_TIME);
@@ -1653,7 +1718,7 @@ void cb2Bib::anyPattern()
     if (_taggedViewMode)
         ClipEdit->insertTag("<AnyPattern>");
     else
-        ClipEdit->insertPlainText("");
+        ClipEdit->insertPlainText(QString());
 }
 
 void cb2Bib::preparseClipboard()
@@ -1694,7 +1759,7 @@ void cb2Bib::dataChanged(const QString& str)
         if (BibBrowser->textCursor().hasSelection())
             do_allow = false;
     }
-    if (_connected && ui.connectB->isEnabled() && do_allow)
+    if (_connected && ui.ConnectB->isEnabled() && do_allow)
         forceDataChange(str);
 }
 
@@ -1715,12 +1780,12 @@ void cb2Bib::c2bInit()
     _dropped_document_file.clear();
     ui.openFileDocumentAction->setEnabled(false);
     ui.openFileDocumentAction->setText(tr("Open File Document"));
-    ui.file->setStatusTip("");
+    ui.file->setStatusTip(QString());
     disconnect(_bpP, SIGNAL(setDocumentFilename()), this, SLOT(setDocumentFilename()));
     _bpP->clearCurrentReference();
     _is_check_repeated_done = false;
     _modified = false;
-    ui.addBibB->setEnabled(_modified);
+    ui.AddBibB->setEnabled(_modified);
 }
 
 void cb2Bib::c2bParse(const QString& text)
@@ -1824,10 +1889,10 @@ void cb2Bib::insertRegExp()
     c2bSaveRegExp Sdiag(pattern, _raw_input_data, this);
     connect(c2b::clipboard(), SIGNAL(cbDataChanged(const QString&)), &Sdiag, SLOT(updateInput(const QString&)));
     connect(&Sdiag, SIGNAL(savePatternInfo(const QString&, const QString&)), this, SLOT(savePattern(const QString&, const QString&)));
-    ui.connectB->setDisabled(true);
+    ui.ConnectB->setDisabled(true);
     if (Sdiag.exec() == QDialog::Rejected)
         showMessage(tr("Cancelled."));
-    ui.connectB->setDisabled(false);
+    ui.ConnectB->setDisabled(false);
 }
 
 void cb2Bib::savePattern(const QString& rx, const QString& rxname)
@@ -1874,7 +1939,7 @@ void cb2Bib::addToFile(bool ready)
     {
         QMessageBox::information(this, tr("Information - cb2Bib"), tr("Not ready to add reference.\n%2").
                                  arg(c2b::net()->errorString()), QMessageBox::Ok);
-        ui.addBibB->setEnabled(_modified);
+        ui.AddBibB->setEnabled(_modified);
         return;
     }
     QFile file(ui.bibtexfile->currentText());
@@ -1898,7 +1963,7 @@ void cb2Bib::addToFile(bool ready)
                     c2b::showMessage(tr("Unable to insert metadata to file %1.").arg(_target_document_file));
         _is_check_repeated_done = false;
         _modified = false;
-        ui.addBibB->setEnabled(_modified);
+        ui.AddBibB->setEnabled(_modified);
         emit addedBibToFile(ui.bibtexfile->currentText());
     }
     else
@@ -2031,7 +2096,7 @@ void cb2Bib::updateOpenDocuments(const QString& old_name, const QString& new_nam
 void cb2Bib::bibModified(bool modified)
 {
     _modified = modified;
-    ui.addBibB->setEnabled(_modified);
+    ui.AddBibB->setEnabled(_modified);
     if (ui.stackedWidget->currentWidget() == BibBrowser)
         BibBrowser->updatePlainText(_bpP->toBibTeX());
 }
@@ -2082,12 +2147,12 @@ bool cb2Bib::isReferenceRepeated()
 
 void cb2Bib::makeNetQuery()
 {
-    if (!ui.makeNetworkQueryB->isEnabled())
+    if (!ui.MakeNetworkQueryB->isEnabled())
     {
         showMessage(tr("Currently processing previous query. Resubmit later."));
         return;
     }
-    ui.makeNetworkQueryB->setEnabled(false);
+    ui.MakeNetworkQueryB->setEnabled(false);
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
     _netQP->submitQuery(_bpP->currentReference(), ClipEdit->toPlainText(), !_pdfImportP);
 }
@@ -2114,13 +2179,13 @@ void cb2Bib::netQueryEnded(bool succeeded, const QString& targetPDF, const QStri
             fileDropped(previous_article_file);
     }
     QApplication::restoreOverrideCursor();
-    ui.makeNetworkQueryB->setEnabled(true);
+    ui.MakeNetworkQueryB->setEnabled(true);
 }
 
 void cb2Bib::processingEnded()
 {
     if (_settingsP->value("cb2Bib/AutomaticQuery").toBool())
-        if (ui.makeNetworkQueryB->isEnabled() && !_bpP->autoRecognizedString().contains("BibTeX"))
+        if (ui.MakeNetworkQueryB->isEnabled() && !_bpP->autoRecognizedString().contains("BibTeX"))
         {
             makeNetQuery();
             return;
@@ -2144,7 +2209,7 @@ void cb2Bib::openFileDocument()
 
 void cb2Bib::selectFile()
 {
-    const QString fn(c2bFileDialog::getOpenFilename(this, "", _settingsP->fileName("cb2Bib/LastDroppedFile"),
+    const QString fn(c2bFileDialog::getOpenFilename(this, QString(), _settingsP->fileName("cb2Bib/LastDroppedFile"),
                      "Portable Document Format (*.pdf);;DjVu (*.djvu);;Post Script (*.ps);;TeX (*.tex);;All (*)"));
     if (!fn.isEmpty())
         fileDroppedByUser(fn);
@@ -2152,7 +2217,7 @@ void cb2Bib::selectFile()
 
 void cb2Bib::openAnnote()
 {
-    const QString fn(c2bFileDialog::getFilename(this, "", _settingsP->fileName("cb2Bib/LastAnnoteFile"),
+    const QString fn(c2bFileDialog::getFilename(this, QString(), _settingsP->fileName("cb2Bib/LastAnnoteFile"),
                      "Annote HTML output (*.tex.html);;LaTeX (*.tex);;All (*)"));
     if (fn.isEmpty())
         return;
