@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2011 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.5. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef CB2BIB_H
@@ -52,6 +52,7 @@ private:
     QString _dropped_document_file;
     QString _raw_input_data;
     QString _target_document_file;
+    QString buttonStatusTip(const QString& ms, const QKeySequence& ks) const;
     Ui::cb2Bib ui;
     bool _connected;
     bool _is_check_repeated_done;
@@ -103,17 +104,17 @@ private slots:
     void loadSettings();
     void makeNetQuery();
     void netQueryEnded(bool succeeded, const QString& targetPDF, const QString& targetBib);
+    void on_AddBibB_clicked();
+    void on_BibTeXDir_clicked();
+    void on_ConfigureB_clicked();
+    void on_ConnectB_clicked();
+    void on_EditBibTeXB_clicked();
+    void on_ExitB_clicked();
+    void on_MakeNetworkQueryB_clicked();
     void on_PdfImportB_clicked();
-    void on_addBibB_clicked();
-    void on_configureB_clicked();
-    void on_connectB_clicked();
-    void on_editBibTeXB_clicked();
-    void on_exitB_clicked();
-    void on_file_dirs_clicked();
-    void on_makeNetworkQueryB_clicked();
-    void on_searchInFilesB_clicked();
-    void on_viewAboutB_clicked();
-    void on_viewBibB_clicked();
+    void on_SearchInFilesB_clicked();
+    void on_ViewAboutB_clicked();
+    void on_ViewBibB_clicked();
     void openAnnote();
     void openFileDocument();
     void postprocessBibTeX();
@@ -128,6 +129,7 @@ private slots:
     void setWindowTitle(const QString& title = QString());
     void showLink(const QString& ln);
     void showMessage(const QString& ms);
+    void toggleReferenceTabs();
     void updateCheckRepeatedAction();
     void updateOpenDocuments(QObject* obj);
     void updateOpenDocuments(const QString& old_name, const QString& new_name);
