@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2011 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.5. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  *   findDialog was originally adapted from Qt Designer
  *   Copyright (C) 2001 Trolltech AS.  All rights reserved.
@@ -27,22 +27,22 @@ findDialog::findDialog(QWidget* parentw) : QDialog(parentw)
     findAction = new QAction(this);
     addAction(findAction);
     findAction->setShortcut(QKeySequence::Find);
-    findAction->setText(tr("Find in Text"));
-    findAction->setStatusTip(tr("Find in Text"));
+    findAction->setText(tr("Find"));
+    findAction->setStatusTip(tr("Find in text"));
     connect(findAction, SIGNAL(triggered()), this, SLOT(findText()));
 
     findNextAction = new QAction(this);
     addAction(findNextAction);
     findNextAction->setShortcut(QKeySequence::FindNext);
     findNextAction->setText(tr("Find Next"));
-    findNextAction->setStatusTip(tr("Find Next Occurrence"));
+    findNextAction->setStatusTip(tr("Find next occurrence"));
     connect(findNextAction, SIGNAL(triggered()), this, SLOT(findNext()));
 
     findPreviousAction = new QAction(this);
     addAction(findPreviousAction);
     findPreviousAction->setShortcut(QKeySequence::FindPrevious);
     findPreviousAction->setText(tr("Find Previous"));
-    findPreviousAction->setStatusTip(tr("Find Previous Occurrence"));
+    findPreviousAction->setStatusTip(tr("Find previous occurrence"));
     connect(findPreviousAction, SIGNAL(triggered()), this, SLOT(findPrevious()));
 }
 
