@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2011 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.5. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.6. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "qtsingleapplication/src/qtsingleapplication.h"
@@ -102,7 +102,7 @@ int main(int argc, char* argv[])
                 if (c2B.show())
                     code = app.exec();
 #else
-                fprintf(stdout, "The cb2bib Annote is disabled. Recompile using WebKit library.\n");
+                fprintf(stdout, "The cb2Bib Annote is disabled. Recompile using WebKit library.\n");
 #endif
             }
             else
